<!-- markdownlint-disable -->

<a href="..\..\qtstrap\widgets\buttons.py#L0"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

# <kbd>module</kbd> `widgets.buttons`




**Global Variables**
---------------
- **PYQT6**
- **PYQT5**
- **PYSIDE2**
- **PYSIDE6**


---

<a href="..\..\qtstrap\widgets\buttons.py#L4"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>class</kbd> `StateButton`




<a href="..\..\qtstrap\widgets\buttons.py#L17"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `StateButton.__init__`

```python
__init__(*args, **kwargs)
```






---

#### <kbd>property</kbd> StateButton.state







---

<a href="..\..\qtstrap\widgets\buttons.py#L26"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `StateButton.next_state`

```python
next_state()
```





---

<a href="..\..\qtstrap\widgets\buttons.py#L29"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `StateButton.update_icon`

```python
update_icon()
```






---

<a href="..\..\qtstrap\widgets\buttons.py#L34"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>class</kbd> `IconToggleButton`




<a href="..\..\qtstrap\widgets\buttons.py#L35"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `IconToggleButton.__init__`

```python
__init__(*args, **kwargs)
```








---

<a href="..\..\qtstrap\widgets\buttons.py#L45"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `IconToggleButton.update_icon`

```python
update_icon()
```






---

<a href="..\..\qtstrap\widgets\buttons.py#L52"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>class</kbd> `ConfirmToggleButton`




<a href="..\..\qtstrap\widgets\buttons.py#L66"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `ConfirmToggleButton.__init__`

```python
__init__(*args, **kwargs)
```






---

#### <kbd>property</kbd> ConfirmToggleButton.state







---

<a href="..\..\qtstrap\widgets\buttons.py#L88"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `ConfirmToggleButton.check`

```python
check()
```





---

<a href="..\..\qtstrap\widgets\buttons.py#L84"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `ConfirmToggleButton.confirm`

```python
confirm()
```





---

<a href="..\..\qtstrap\widgets\buttons.py#L93"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `ConfirmToggleButton.next_state`

```python
next_state()
```





---

<a href="..\..\qtstrap\widgets\buttons.py#L79"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `ConfirmToggleButton.uncheck`

```python
uncheck()
```





---

<a href="..\..\qtstrap\widgets\buttons.py#L101"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `ConfirmToggleButton.update_icon`

```python
update_icon()
```








---

_This file was automatically generated via [lazydocs](https://github.com/ml-tooling/lazydocs)._
